@@ -31,6 +31,10 @@ class Agent(object):
             Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))
             .get(mac(k, self.__hmac_key)))
 
+    def rm(self, id: str, pw: str, k: str) -> bool:
+        return Broker(app_name=self.__app_name, username=mac(id, self.__hmac_key)+mac(pw, self.__hmac_key))\
+            .rm(mac(k, self.__hmac_key))
+
 
 
 
